==> monodevelop-2.4.tar.bz2: monodevelop-2.4/src/addins/CSharpBinding/MonoDevelop.CSharp.Formatting/Indent.cs <==
// 
// Indent.cs
//  
// Author:
//       Mike Krüger <mkrueger@novell.com>
// 
// Copyright (c) 2010 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;

namespace MonoDevelop.CSharp.Formatting
{
	public class Indent
	{
		public int Level {
			get;
			set;
		}
		
		public int ExtraSpaces {
			get;
			set;
		}
		
		public Indent ()
		{
		}
		
		public Indent (int level, int extraSpaces)
		{
			this.Level = level;
			this.ExtraSpaces = extraSpaces;
		}
		
		public static Indent operator+(Indent left, Indent right)
		{
			return new Indent (left.Level + right.Level, left.ExtraSpaces + right.ExtraSpaces);
		}
		
		public static Indent operator-(Indent left, Indent right)
		{
			return new Indent (left.Level - right.Level, left.ExtraSpaces - right.ExtraSpaces);
		}
		
		public string IndentString {
			get {
				return new string ('\t', Level) + new string (' ', ExtraSpaces);
			}
		}
		
		public string SingleIndent {
			get {
				return "\t";
			}
		}
		
		public override string ToString ()
		{
			return string.Format ("[Indent: Level={0}, ExtraSpaces={1}]", Level, ExtraSpaces);
		}
	}
}

==> monodevelop_5.10.0.871.orig.tar.bz2: monodevelop-5.10/src/addins/CSharpBinding/MonoDevelop.CSharp.Formatting/Indent.cs <==
// 
// Indent.cs
//  
// Author:
//       Mike Krüger <mkrueger@novell.com>
// 
// Copyright (c) 2010 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

namespace MonoDevelop.CSharp.Formatting
{
	class Indent
	{
		public int Level {
			get;
			set;
		}
		
		public int ExtraSpaces {
			get;
			set;
		}
		
		public bool TabsToSpaces {
			get;
			set;
		}
		
		public int TabSize {
			get;
			set;
		}
		
		public Indent ()
		{
		}
		
		public Indent (int level, int extraSpaces)
		{
			this.Level = level;
			this.ExtraSpaces = extraSpaces;
		}
		
		public static Indent operator+(Indent left, Indent right)
		{
			return new Indent (left.Level + right.Level, left.ExtraSpaces + right.ExtraSpaces);
		}
		
		public static Indent operator-(Indent left, Indent right)
		{
			return new Indent (left.Level - right.Level, left.ExtraSpaces - right.ExtraSpaces);
		}
		
		public string IndentString {
			get {
				return (TabsToSpaces ? new string (' ', Level * TabSize) : new string ('\t', Level)) + new string (' ', ExtraSpaces);
			}
		}
		
		public string SingleIndent {
			get {
				return TabsToSpaces ? new string (' ', TabSize) : "\t";
			}
		}
		
		public override string ToString ()
		{
			return string.Format ("[Indent: Level={0}, ExtraSpaces={1}]", Level, ExtraSpaces);
		}
	}
}
